﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2016 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Collections.Generic;
using System.Linq;
using System.Windows.Forms;
using HeuristicLab.MainForm;

namespace HeuristicLab.Problems.DataAnalysis.Views {
  [View("Gradient View")]
  [Content(typeof(IRegressionSolution), false)]
  public partial class RegressionSolutionGradientView : DataAnalysisSolutionEvaluationView {
    public RegressionSolutionGradientView() {
      InitializeComponent();
    }

    public new IRegressionSolution Content {
      get { return (IRegressionSolution)base.Content; }
      set {
        if (value == null || value == Content) return;
        base.Content = value;
      }
    }

    protected override void OnContentChanged() {
      base.OnContentChanged();
      if (Content == null) return;
      var variable = Content.ProblemData.AllowedInputVariables.First();
      var values = (IList<double>)Content.ProblemData.Dataset.GetReadOnlyDoubleValues(variable);
      gradientChart1.Configure(new[] { Content }, Content.ProblemData, values.Min(), values.Max(), 1000);
      UpdateVariableList();
    }

    protected virtual void UpdateVariableList() {
      variableComboBox.Items.Clear();
      var variables = Content.ProblemData.AllowedInputVariables.ToArray();
      variableComboBox.Items.AddRange(variables);
      variableComboBox.Text = variables[0];
    }

    private void variableComboBox_SelectedIndexChanged(object sender, System.EventArgs e) {
      gradientChart1.Variable = variableComboBox.Text;
    }
  }
}
